#!/usr/bin/env python
from __future__ import division

import sys

from Numeric import *
import numpy as np

from matplotlib import rc
import matplotlib.pyplot as plot

def main():

	rc('text', usetex=True)	

	S = np.arange(2,10,1)
	X = np.arange(0, 1.01, 0.01)
	
	plot.subplot(1,2,1)
	
	# Renyi
	A = 0.5
	UA = 1/(1-A)
	HR = [UA*np.log2(pow(x,A)+pow((1-x),A)) for x in X[1:-1]] 
	HR.insert(0,0)
	HR.append(0)
	plot.plot(X, HR)
	txtA1 = (r'$\displaystyle\alpha=0.5$')
	#plot.text(0.10, 0.85, txtA3, fontsize=12)
	
	# Shannon
	HS = [(-x*np.log2(x)-(1-x)*np.log2(1-x)) for x in X[1:-1]]
	HS.insert(0,0)
	HS.append(0)	
	plot.plot(X, HS)
	txtA2 = (r'$\displaystyle\alpha\rightarrow 1$')
	#plot.text(0.18, 0.65, txtA1, fontsize=12)
	
	# Renyi
	A = 5
	UA = 1/(1-A)
	HR = [UA*np.log2(pow(x,A)+pow((1-x),A)) for x in X[1:-1]] 
	HR.insert(0,0)
	HR.append(0)
	plot.plot(X, HR)
	txtA3 = (r'$\displaystyle\alpha=5$')
	#plot.text(0.30, 0.55, txtA2, fontsize=12)
	
	plot.title(r'\textit{R\'enyie Entropies}', fontsize=13)
	plot.xlabel(r'$\displaystyle\,p$', fontsize=17)
	plot.ylabel(r'$\displaystyle\,H_{\alpha}\left(p,\left(1-p\right)\right)$', fontsize=17)
	plot.axis([0, 1, 0, 1], picker=0.1)

	leg = plot.legend((txtA1,txtA2,txtA3), 'center', shadow=True)
	# the matplotlib.patches.Rectangle instance surrounding the legend
	#frame  = leg.get_frame()  
	#frame.set_facecolor('0.80')    # set the frame face color to light gray
	# matplotlib.text.Text instances
	for t in leg.get_texts():
		t.set_fontsize('small')    # the legend text fontsize
		# matplotlib.lines.Line2D instances
		for l in leg.get_lines():
			l.set_linewidth(1.5)  # the legend line width
	
	plot.subplot(1,2,2)

	# Daroczy
	B = 0.5
	UB = pow(2,B-1)/(pow(2,B-1)-1)
	HD = [(x*UB*(1-pow(x,B-1))+(1-x)*UB*(1-pow((1-x),B-1))) for x in X[1:-1]] 
	HD.insert(0,0)
	HD.append(0)
	plot.plot(X, HD, label='B0.5')
	txtB1 = (r'$\displaystyle\beta=0.5$')
	#plot.text(0.05, 0.80, txtB2, fontsize=12)
	
	# Shannon
	HS = [(-x*np.log2(x)-(1-x)*np.log2(1-x)) for x in X[1:-1]]
	HS.insert(0,0)
	HS.append(0)	
	plot.plot(X, HS, label='B1')
	txtB2 = (r'$\displaystyle\beta\rightarrow 1$')
	#plot.text(0.20, 0.65, txtB1, fontsize=12)
	
	# Gini
	#B = 2
	#UB = pow(2,B-1)/(pow(2,B-1)-1)
	#HD = [(x*UB*(1-pow(x,B-1))+(1-x)*UB*(1-pow((1-x),B-1))) for x in X] 
	#plt.plot(X, HD)
	HG = [4*x*(1-x) for x in X]
	plot.plot(X, HG, label='B2')
	txtB3 = (r'$\displaystyle\beta=2$')
	#plot.text(0.60, 0.45, txtB3, fontsize=12)
	
	plot.title(r'\textit{Dar\'oczy Entropies}', fontsize=13)
	plot.xlabel(r'$\displaystyle\,p$', fontsize=17)
	plot.ylabel(r'$\displaystyle\,H_{\beta}\left(p,\left(1-p\right)\right)$', fontsize=17)
	plot.axis([0, 1, 0, 1], picker=0.1)

	leg = plot.legend((txtB1,txtB2,txtB3), 'center', shadow=True)
	# the matplotlib.patches.Rectangle instance surrounding the legend
	#frame  = leg.get_frame()  
	#frame.set_facecolor('0.80')    # set the frame face color to light gray
	# matplotlib.text.Text instances
	for t in leg.get_texts():
		t.set_fontsize('small')    # the legend text fontsize
		# matplotlib.lines.Line2D instances
		for l in leg.get_lines():
			l.set_linewidth(1.5)  # the legend line width
	
	plot.show()
		

if __name__ == "__main__":
	main()
	
