#!/usr/bin/env python
from __future__ import division

import sys

from Numeric import *
import numpy as np
from matplotlib import rc
import matplotlib.pyplot as plt

def main():

	z = 2
	S = 20
	C = np.arange(z, S, 1);
	xt = np.arange(z, S, 2);
	
	pm = 0.50
	pj = 0.50
	
	width = 0.5
	
	rc('text', usetex=True)	
	
	fig = plt.figure()
	
	entPlt = fig.add_subplot(121)
	
	runners = []
	runners.append([])
#	cmap = ['b']
	cmap = ['0.15']	# dark gray
	for s in range(z,S):
		runners[0].append(ent(pm))
			
	odd = 0
	for i in range(1,S):
		runners.append([])
		if (odd):
#			cmap.append('r')
			cmap.append('0.45')	# medium gray
			odd = 0
		else:
#			cmap.append('m')
			cmap.append('0.75')	# light gray
			odd = 1
		for s in range(z,S):
			if (s > i):
				runners[i].append(ent(pj/(s-1)))
			else:
				runners[i].append(0)

	bttm = []
	for s in range(S-z):
		bttm.append(0)
	
	for i in range(S):
		entPlt.bar(C, runners[i], width, color=cmap[i], bottom=bttm, linewidth=0)
		bttm = [x+y for x,y in zip(bttm,runners[i])]
	
	plt.text(6.5, 3.5, r'$\displaystyle H_{s}\left(\mathcal{P}\right)=-\sum^{s}_{i=1}p_{i}\;log\,p_{i}$', fontsize=14)
	plt.xlabel(r'\textit{Cardinality (s)}', fontsize=12)
	plt.ylabel(r'\textit{Uncertainty:}$\displaystyle \quad H_{s}(\mathcal{P})$', fontsize=12)
	plt.xticks(xt+width/2,xt)
	plt.yticks(np.arange(0,log(S-1)/log(2),0.2))
	

	knwPlt = fig.add_subplot(122)
	
	runners = []
	runners.append([])
#	cmap = ['b']
	cmap = ['0.15']	# dark grey
	for s in range(z,S):
		runners[0].append(knw(pm,s))
			
	odd = 0
	for i in range(1,S):
		runners.append([])
		if (odd):
#			cmap.append('r')
			cmap.append('0.45')
			odd = 0
		else:
#			cmap.append('m')
			cmap.append('0.75')
			odd = 1
		for s in range(z,S):
			if (s > i):
				runners[i].append(knw(pj/(s-1),s))
			else:
				runners[i].append(0)

	bttm = []
	for s in range(S-z):
		bttm.append(0)
	
	for i in range(S):
		knwPlt.bar(C, runners[i], width, color=cmap[i], bottom=bttm, linewidth=0)
		bttm = [x+y for x,y in zip(bttm,runners[i])]
	
	#plt.text(6, 0.45, r'$\displaystyle K_{s}\left(\mathcal{P}\right)=\sum^{s}_{i=1}\left(p_{i}\frac{1}{s}+\left(p_{i}-\frac{1}{s}\right)^{2}\right)$', fontsize=14)
	plt.text(6, 0.45, r'$\displaystyle K_{s}\left(\mathcal{P}\right)=\sum^{s}_{i=1}\left(\frac{1}{s^{2}}+\left(p_{i}-\frac{1}{s}\right)^{2}\right)$', fontsize=14)
	plt.xlabel(r'\textit{Cardinality (s)}', fontsize=12)
	plt.ylabel(r'\textit{Certainty:}$\displaystyle \quad K_{s}(\mathcal{P})$', fontsize=12)
	plt.xticks(xt+width/2,xt)
	plt.yticks(np.arange(0,0.6,0.05))

	plt.show()
	

def ent(val):
	if (val == 0): return 0
	return -val*log(val)/log(2)
		
	
def knw(val,s):
	if (s == 0): return 0
	Us = 1.0/s
	#return val*Us + (val-Us)**2
	return  Us**2 + (val-Us)**2

if __name__ == "__main__":
	main()
	
