#!/usr/bin/env python
from __future__ import division

import sys

from Numeric import *
import numpy as np

from matplotlib import rc
import matplotlib.pyplot as plot

def main():

	rc('text', usetex=True)	

	S = np.asarray([2,3,4,5,7,10,20,50])
	X = np.arange(0, 1.01, 0.01)
	
	plot.subplot(131)
	
	# Renyi
	HR = [-np.log2(x) for x in X[1:]] 
	HR.insert(0,1000000)	
	plot.plot(X, HR)
	txt1 = (r'$\displaystyle\beta\rightarrow 1$')
	#plot.text(0.15, 2.10, txt, fontsize=12)
	
	# Daroczy
	B = 0.5
	UB = pow(2,B-1)/(pow(2,B-1)-1)
	HD = [UB*(1-pow(x,B-1)) for x in X] 
	plot.plot(X, HD)
	txt2 = (r'$\displaystyle\beta=0.5$')
	#plot.text(0.30, 2.25, txt, fontsize=12)

	B = 2
	UB = pow(2,B-1)/(pow(2,B-1)-1)
	HD = [UB*(1-pow(x,B-1)) for x in X] 
	plot.plot(X, HD)
	txt3 = (r'$\displaystyle\beta=2$')
	#plot.text(0.05, 1.60, txt, fontsize=12)

	B = 3
	UB = pow(2,B-1)/(pow(2,B-1)-1)
	HD = [UB*(1-pow(x,B-1)) for x in X] 
	plot.plot(X, HD)
	txt4 = (r'$\displaystyle\beta=3$')
	#plot.text(0.05, 1.15, txt, fontsize=12)

	B = 10
	UB = pow(2,B-1)/(pow(2,B-1)-1)
	HD = [UB*(1-pow(x,B-1)) for x in X] 
	plot.plot(X, HD)
	txt5 = (r'$\displaystyle\beta=10$')
	#plot.text(0.05, 0.85, txt, fontsize=12)
	
	plot.title(r'\textit{single Entropy}', fontsize=12)
	plot.xlabel(r'$\displaystyle\,p_{i}$', fontsize=15)
	plot.ylabel(r'$\displaystyle\,u^{\beta}\left(p_{i}\right)$', fontsize=15)
	plot.axis([0, 1, 0, 3], picker=0.1)
	plot.grid()

	leg = plot.legend((txt1,txt2,txt3,txt4,txt5), 'upper right', shadow=True)
	# the matplotlib.patches.Rectangle instance surrounding the legend
	#frame  = leg.get_frame()  
	#frame.set_facecolor('0.80')    # set the frame face color to light gray
	# matplotlib.text.Text instances
	for t in leg.get_texts():
		t.set_fontsize('small')    # the legend text fontsize
		# matplotlib.lines.Line2D instances
		for l in leg.get_lines():
			l.set_linewidth(1.5)  # the legend line width
	
	plot.subplot(132)
	
	# Shannon & Renyi
	HS = [-x*np.log2(x) for x in X[1:]]
	HS.insert(0,0)	
	plot.plot(X, HS)
	#txt = (r'$\displaystyle\beta\rightarrow 1$')
	#plot.text(0.45, 0.25, txt, fontsize=12)
	
	# Daroczy
	B = 0.5
	UB = pow(2,B-1)/(pow(2,B-1)-1)
	HD = [x*UB*(1-pow(x,B-1)) for x in X[1:]] 
	HD.insert(0,0)	
	plot.plot(X, HD)
	#txt = (r'$\displaystyle\beta=0.5$')
	#plot.text(0.55, 0.40, txt, fontsize=12)

	B = 2
	UB = pow(2,B-1)/(pow(2,B-1)-1)
	HD = [x*UB*(1-pow(x,B-1)) for x in X] 
	plot.plot(X, HD)
	#txt = (r'$\displaystyle\beta=2$')
	#plot.text(0.60, 0.45, txt, fontsize=12)

	B = 3
	UB = pow(2,B-1)/(pow(2,B-1)-1)
	HD = [x*UB*(1-pow(x,B-1)) for x in X] 
	plot.plot(X, HD)
	#txt = (r'$\displaystyle\beta=3$')
	#plot.text(0.65, 0.50, txt, fontsize=12)

	B = 10
	UB = pow(2,B-1)/(pow(2,B-1)-1)
	HD = [x*UB*(1-pow(x,B-1)) for x in X] 
	plot.plot(X, HD)
	#txt = (r'$\displaystyle\beta=10$')
	#plot.text(0.75, 0.60, txt, fontsize=12)
	
	plot.xticks(np.arange(0,1.1,0.1))
	plot.yticks(np.arange(0,1.1,0.1))
	plot.title(r'\textit{weighted contribution}', fontsize=12)
	plot.xlabel(r'$\displaystyle\,p_{i}$', fontsize=15)
	plot.ylabel(r'$\displaystyle\,p_{i}\;u^{\beta}\left(p_{i}\right)$', fontsize=15)
	plot.axis([0, 1, 0, 1], picker=0.1)
	plot.grid()

	plot.subplot(133)

	for s in S:
		Us = 1.0/s
		K = [Us**2+(x-Us)**2 for x in X] 
		plot.plot(X, K)
	
	plot.xticks(np.arange(0,1.1,0.1))
	plot.yticks(np.arange(0,1.1,0.1))
	plot.title(r'Certainty, $\;s=\left(2,3,4,5,7,10,20,50\right)$', fontsize=12)
	plot.xlabel(r'$\displaystyle\,p_{i}$', fontsize=15)
	plot.ylabel(r'$K\left(p_{i}\right)$', fontsize=15)
	plot.axis([0, 1, 0, 1], picker=0.1)
	plot.grid()
	
	plot.show()
		

if __name__ == "__main__":
	main()
	
