#!/usr/bin/env python
from __future__ import division

import sys

from Numeric import *
import numpy as np
from matplotlib import rc
import matplotlib.pyplot as plt

def main():

	rc('text', usetex=True)	

	S = np.asarray([2,3,4,5,6,8,10,15,20,50])
	X = np.arange(0, 1.01, 0.01)

	plt.subplot(131)
	for s in S:
		Y = []				
		Us = 1.0/s
		for x in X:
			Y.append(Us**2+(x-Us)**2)
		plt.plot(X, Y)
	
	plt.xticks(np.arange(0,1.1,0.1))
	plt.yticks(np.arange(0,1.1,0.1))
	plt.grid()
	plt.title(r'Certainty', fontsize=12)
	plt.xlabel(r'$p_{i}$')
	plt.ylabel(r'$K(p_{i})$')
	
	plt.subplot(1,3,2)
	for s in S:
		Y = []				
		Us = 1.0/s
		for x in X:
			Y.append(sqrt(Us**2+(x-Us)**2))
		plt.plot(X, Y)
	
	plt.xticks(np.arange(0,1.1,0.1))
	plt.yticks(np.arange(0,1.1,0.1))
	plt.grid()
	plt.title('sqrt Certainty', fontsize=12)
	plt.xlabel(r'$p_{i}$')
	plt.ylabel(r'$\sqrt{K(p_{i})}$')
	
	plt.subplot(1,3,3)
	for s in S:
		Y = []				
		Us = 1.0/s
		for x in X:
			if x < Us:
				Y.append(Us - (sqrt(Us**2+(x-Us)**2)-Us))
			else:
				Y.append(sqrt(Us**2+(x-Us)**2))
		plt.plot(X, Y)
	
	plt.xticks(np.arange(0,1.1,0.1))
	plt.yticks(np.arange(0,1.1,0.1))
	plt.grid()
	plt.title('Smoothed Parametric Model', fontsize=12)
	plt.xlabel(r'$p_{i}$')
	plt.ylabel(r'$\theta_{i}$')
	
	plt.show()
		

if __name__ == "__main__":
	main()
	
